Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(458)

Unified Diff: src/heap.cc

Issue 174050: Temporarily revert the reduction of semispace sizes and the growth... (Closed) Base URL: http://v8.googlecode.com/svn/branches/bleeding_edge/
Patch Set: Created 11 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | src/spaces.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/heap.cc
===================================================================
--- src/heap.cc (revision 2711)
+++ src/heap.cc (working copy)
@@ -74,11 +74,11 @@
int Heap::old_generation_size_ = 128*MB;
int Heap::initial_semispace_size_ = 128*KB;
#elseif defined(V8_TARGET_ARCH_X64)
-int Heap::semispace_size_ = 8*MB;
+int Heap::semispace_size_ = 16*MB;
int Heap::old_generation_size_ = 1*GB;
int Heap::initial_semispace_size_ = 1*MB;
#else
-int Heap::semispace_size_ = 4*MB;
+int Heap::semispace_size_ = 8*MB;
int Heap::old_generation_size_ = 512*MB;
int Heap::initial_semispace_size_ = 512*KB;
#endif
@@ -661,11 +661,11 @@
if (new_space_.Capacity() < new_space_.MaximumCapacity() &&
survived_since_last_expansion_ > new_space_.Capacity()) {
// Grow the size of new space if there is room to grow and enough
// data has survived scavenge since the last expansion.
// TODO(1240712): NewSpace::Grow has a return value which is
// ignored here.
- new_space_.Grow();
+ new_space_.Double();
survived_since_last_expansion_ = 0;
}
« no previous file with comments | « no previous file | src/spaces.h » ('j') | no next file with comments »
@@ -661,11 +661,11 @@
if (new_space_.Capacity() < new_space_.MaximumCapacity() &&
survived_since_last_expansion_ > new_space_.Capacity()) {
- // Grow the size of new space if there is room to grow and enough
+ // Double the size of new space if there is room to grow and enough
// data has survived scavenge since the last expansion.
@@ -661,11 +661,11 @@
// data has survived scavenge since the last expansion.
- // TODO(1240712): NewSpace::Grow has a return value which is
+ // TODO(1240712): NewSpace::Double has a return value which is
// ignored here.

Powered by Google App Engine
This is Rietveld 408576698